#
# spec file for package libqt5-qtmultimedia
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define qt5_snapshot 0
%define libname libQt5Multimedia5

%ifarch %arm aarch64
%define gles 1
%else
%define gles 0
%endif

Name:           libqt5-qtmultimedia
Version:        5.6.2
Release:        1.4
Summary:        Qt 5 Multimedia Library
License:        SUSE-LGPL-2.1-with-digia-exception-1.1 or GPL-3.0
Group:          Development/Libraries/X11
Url:            http://qt.digia.com
%define base_name libqt5
%define real_version 5.6.2
%define so_version 5.6.2
%define tar_version qtmultimedia-opensource-src-%{real_version}
Source:         %{tar_version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  alsa-devel
BuildRequires:  fdupes
%if 0%{?suse_version} < 1315
BuildRequires:  pkgconfig(gstreamer-0.10)
BuildRequires:  pkgconfig(gstreamer-app-0.10)
BuildRequires:  pkgconfig(gstreamer-base-0.10)
BuildRequires:  pkgconfig(gstreamer-interfaces-0.10)
BuildRequires:  pkgconfig(gstreamer-pbutils-0.10)
BuildRequires:  pkgconfig(gstreamer-plugins-base-0.10)
BuildRequires:  pkgconfig(gstreamer-video-0.10)
%else
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-app-1.0)
BuildRequires:  pkgconfig(gstreamer-base-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-bad-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
%endif
BuildRequires:  libQt5Gui-private-headers-devel >= %{version}
BuildRequires:  libQt5Widgets-private-headers-devel >= %{version}
BuildRequires:  libpulse-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libwmf-devel
BuildRequires:  pkgconfig(Qt5Qml) >= %{version}
BuildRequires:  pkgconfig(Qt5Quick) >= %{version}
%if 0%{?suse_version} != 1315 || 0%{?is_opensuse}
BuildRequires:  pkgconfig(openal)
%endif
%if %qt5_snapshot
#to create the forwarding headers
BuildRequires:  perl
%endif
BuildRequires:  xz

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Qt is a set of libraries for developing applications.

This package contains base tools, like string, xml, and network
handling.

%prep
%setup -q -n qtmultimedia-opensource-src-%{real_version}

%package -n %libname
Summary:        Qt 5 Multimedia Library
Group:          Development/Libraries/X11

%description -n %libname
Qt is a set of libraries for developing applications.

This package contains base tools, like string, xml, and network
handling.

%package devel
Summary:        Qt Development Kit
Group:          Development/Libraries/X11
Requires:       %libname = %{version}
Requires:       libqt5-qtdeclarative-devel >= %{version}
Suggests:       libpulse-devel
Suggests:       libwmf-devel
Suggests:       openal-soft-devel
Provides:       libQt5Multimedia-devel = %{version}
Obsoletes:      libQt5Multimedia-devel < %{version}

%description devel
You need this package, if you want to compile programs with qtmultimedia.

%package private-headers-devel
Summary:        Non-ABI stable experimental API
Group:          Development/Libraries/C and C++
BuildArch:      noarch
Requires:       %{name}-devel = %{version}
Requires:       libQt5Gui-private-headers-devel >= %{version}
Requires:       libQt5Widgets-private-headers-devel >= %{version}
Provides:       libQt5Multimedia-private-headers-devel = %{version}
Obsoletes:      libQt5Multimedia-private-headers-devel < %{version}

%description private-headers-devel
This package provides private headers of libqt5-qtmultimedia that are normally
not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package examples
Summary:        Qt5 multimedia examples
Group:          Development/Libraries/X11
Recommends:     %{name}-devel

%description examples
Examples for libqt5-qtmultimedia module.

%post -n %libname -p /sbin/ldconfig

%postun -n %libname -p /sbin/ldconfig

%build
%if 0%{?suse_version} >= 1315
GST="1.0"
%else
GST="0.10"
%endif
%if %qt5_snapshot
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
%endif
%qmake5 GST_VERSION=$GST
%make_jobs

%install
%qmake5_install
find %{buildroot}/%{_libdir} -type f -name '*la' -print -exec perl -pi -e 's, -L%{_builddir}/\S+,,g' {} \;
find %{buildroot}/%{_libdir} -type f -name '*pc' -print -exec perl -pi -e "s, -L$RPM_BUILD_DIR/?\S+,,g" {} \; -exec sed -i -e "s,^moc_location=.*,moc_location=%{_lib}qt5_bindir/moc," -e "s,uic_location=.*,uic_location=%{_lib}qt5_bindir/uic," {} \;
# kill .la files
rm -f %{buildroot}%{_libqt5_libdir}/lib*.la

%fdupes -s %{buildroot}/%{_libqt5_includedir}

%files -n %libname
%defattr(-,root,root,755)
%doc LGPL_EXCEPTION.txt LICENSE.*
%{_libqt5_libdir}/libQt5*.so.*
%{_libqt5_plugindir}/mediaservice
%{_libqt5_plugindir}/playlistformats
%{_libqt5_libdir}/libqgsttools_p.so.*
%{_libqt5_plugindir}/audio
%if %gles
%{_libqt5_plugindir}/video
%endif
%{_libqt5_archdatadir}/qml/Qt*

%files private-headers-devel
%defattr(-,root,root,755)
%doc LGPL_EXCEPTION.txt LICENSE.*
%{_libqt5_includedir}/Qt*/%{so_version}

%files devel
%defattr(-,root,root,755)
%doc LGPL_EXCEPTION.txt LICENSE.*
%exclude %{_libqt5_includedir}/Qt*/%{so_version}
%{_libqt5_includedir}/Qt*
%{_libqt5_libdir}/cmake/Qt5*
%{_libqt5_libdir}/libQt5*.prl
%{_libqt5_libdir}/libQt5*.so
%{_libqt5_libdir}/pkgconfig/Qt5*.pc
%{_libqt5_archdatadir}/mkspecs/modules/qt_lib_*.pri
%{_libqt5_libdir}/libqgsttools_p.so
%{_libqt5_libdir}/libqgsttools_p.prl

%files examples
%defattr(-,root,root,755)
%doc LGPL_EXCEPTION.txt LICENSE.*
%{_libqt5_examplesdir}/

%changelog
* Mon Mar  6 2017 mlin@suse.com
- Update to 5.6.2 (bsc#1028654)
  * 5.6 bugfix release http://blog.qt.io/blog/2016/10/12/qt-5-6-2-released/
* Tue Jun 14 2016 mlin@suse.com
- Update to 5.6.1 (boo#984605)
  * For more details please see:
    http://blog.qt.io/blog/2016/06/08/qt-5-6-1-released/
* Fri Apr  8 2016 alarrosa@suse.com
- Updated Qt to 5.6.0, a LTS release (fate#320330)
* Wed Mar 23 2016 alarrosa@suse.com
- Remove openal requirement in SLE12 where that dependency is not available
* Fri Mar 18 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    http://blog.qt.io/blog/2016/03/16/qt-5-6-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.6
* Wed Feb  3 2016 alarrosa@suse.com
- [ECO] Update Qt5 to version 5.5.1 (fate#319961, bnc#964864)
* Fri Oct 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1
  * For more details please see:
    http://blog.qt.io/blog/2015/10/15/qt-5-5-1-released/
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * For more details please see:
    http://blog.qt.io/blog/2015/07/01/qt-5-5-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.5
- Drop 0001-GStreamer-port-to-1.0.patch, merged upstream
- Enable openal support on Leap
* Wed Jun  3 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2
  * Bugfix release, for more details please see:
    http://blog.qt.io/blog/2015/06/02/qt-5-4-2-released/
* Wed May 20 2015 mlin@suse.com
- A bunch update to Qt5 5.3.2 for SLE12 SP1, bsc#931622
* Wed Sep 17 2014 idonmez@suse.com
- Remove openal dependency bnc#886207
* Tue Sep 16 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2 final
  * No changes since previous snapshot
  * Use official tars
* Thu Sep  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2~git20140904 (r6e39a79):
  * Tip of the bugfix 5.3.2 branch
  * MediaPlayer's loops property now works correctly when
    playing a media from a qrc file.
  * [QTBUG-29742] Fixed Qt apps hanging when audio APIs are
    used and PulseAudio is not running.
  * [QTBUG-39949] Fixed QMediaRecorder::setOutputLocation() not
    working with QUrl::fromLocalFile().
- Rebase Initial-porting-effort-to-GStreamer-1.0.patch
* Wed Jun 25 2014 hrvoje.senjan@gmail.com
- Update to 5.3.1
  * Bugfix release, for more details please see:
    http://blog.qt.digia.com/blog/2014/06/25/qt-5-3-1-released/
* Thu Jun  5 2014 fcrozat@suse.com
- Switch SLE12 to gstreamer-1.0 API too.
* Mon Jun  2 2014 hrvoje.senjan@gmail.com
- Add baselibs.conf
- Make private headers noarch
* Mon May 19 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 final
  * Minor bugfixes over previous RC
* Thu May  8 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 RC
  * For more details, please see
  http://blog.qt.digia.com/blog/2014/05/08/qt-5-3-release-candidate-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.3
* Wed Apr  2 2014 hrvoje.senjan@gmail.com
- Added Initial-porting-effort-to-GStreamer-1.0.patch: support
  building with gstreamer 1.0 API (taken from upstream
  wip/gstreamer-1.0 branch) and apply it for >= 13.2
- Shuffle and add BuildRequires: for older than 13.2, add:
  pkgconfig(gstreamer-0.10), pkgconfig(gstreamer-app-0.10),
  pkgconfig(gstreamer-base-0.10), pkgconfig(gstreamer-interfaces-0.10),
  pkgconfig(gstreamer-pbutils-0.10), pkgconfig(gstreamer-plugins-base-0.10)
  and pkgconfig(gstreamer-video-0.10).
  For 13.2 and newer add: pkgconfig(gstreamer-1.0), pkgconfig(gstreamer-app-1.0),
  pkgconfig(gstreamer-base-1.0), pkgconfig(gstreamer-pbutils-1.0),
  pkgconfig(gstreamer-plugins-base-1.0) and pkgconfig(gstreamer-video-1.0)
* Tue Mar 25 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 beta
  * New feature release, please see
  http://blog.qt.digia.com/blog/2014/03/25/qt-5-3-beta-released/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.3
* Fri Mar 21 2014 hrvoje.senjan@gmail.com
- Build, and add examples subpackage
- Swap pkgconfig(Qt5Core), pkgconfig(Qt5Gui), pkgconfig(Qt5Network),
  pkgconfig(Qt5OpenGL) and pkgconfig(Qt5Widgets) BuildRequires, for
  full libqt5-qtbase-devel, examples need more modules
* Mon Feb 10 2014 mlin@suse.com
- Install LICENSE files to %%doc
* Wed Feb  5 2014 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/02/05/qt-5-2-1-released/
- Remove libtool archives from packages
* Mon Dec 16 2013 hrvoje.senjan@gmail.com
- Make devel packages naming consistent:
  use libqt5-$upstreammodulename-(devel, private-headers-devel)
* Thu Dec 12 2013 hrvoje.senjan@gmail.com
- Update to 5.2.0 final:
  * For more details please see:
    http://blog.qt.digia.com/blog/2013/12/12/qt-5-2-released-the-best-qt-yet/
    http://qt-project.org/qt5/qt52
    http://qt.digia.com/Product/Whats-New/Qt-52/"
* Fri Nov 29 2013 hrvoje.senjan@gmail.com
- Update to 5.2 rc1
  * New feature release, please see
  http://blog.qt.digia.com/blog/2013/11/29/qt-5-2-release-candidate-1-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.2
* Wed Oct 23 2013 hrvoje.senjan@gmail.com
- Update to 5.2 beta1
  * New feature release, please see
  http://blog.qt.digia.com/blog/2013/10/23/qt-5-2-beta-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.2
* Thu Aug 29 2013 hrvoje.senjan@gmail.com
- Update to version 5.1.1:
  * Bugfix release, please see
  http://blog.qt.digia.com/blog/2013/08/28/qt-5-1-1-released/
  http://qt.gitorious.org/qt/qtmultimedia/blobs/release/dist/changes-5.1.1
  and http://qt-project.org/wiki/Qt511KnownIssues for known issues
- Small spec cleanup
* Sat Aug  3 2013 tittiatcoke@gmail.com
- Adjust package naming to Factory standards
* Sun Jul  7 2013 stephan.binner@basyskom.com
- update to Qt 5.1 release
* Tue Jun 18 2013 stephan.binner@basyskom.com
- update to Qt 5.1 RC 1
* Mon May 20 2013 stephan.binner@basyskom.com
- update to Qt 5.1 Beta 1
* Tue Apr  9 2013 stephan.binner@basyskom.com
- update to Qt 5.1 Alpha 1
* Wed Jan 30 2013 stephan.binner@basyskom.com
- update to Qt 5.0.1
* Wed Dec 19 2012 stephan.binner@basyskom.com
- update to Qt 5.0 release
* Thu Dec 13 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Release Candidate 2
* Thu Dec  6 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Release Candidate 1
* Thu Nov 15 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Beta 2
* Thu Aug 30 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Beta 1 release
* Thu May 24 2012 stephan.binner@basyskom.com
- update to newer Alpha snapshot / Beta candidate
* Fri Apr 13 2012 stephan.binner@basyskom.com
- rework package splitting for Qt 5 modularization
* Thu Apr  5 2012 dmueller@suse.com
- Initial packaging (Qt 5.0 Alpha)
